class CustomReport < ActiveRecord::Base
  unloadable

  belongs_to :group, :class_name => "NodeGroup"
  belongs_to :against_baseline, :class_name => "NodeBaseline", :foreign_key => 'node_baseline_id'
  has_and_belongs_to_many :node_baselines
  has_many :baseline_differences, :through => :node_baselines, :source => :differences

  def before_create
    super
    self.node_count = group.nodes.count
  end

  def ready?
    node_baselines.diffed.count == self.node_count
  end

  def percent_complete
    # While we shouldn't ever hit the case where we create a custom report for
    # an empty group, better to be defensive here. --daniel 2011-08-18
    return 0 if self.node_count == 0
    (100.0 * node_baselines.count / self.node_count).floor
  end

  def title
    ready? ? group.name : "#{group.name} (#{percent_complete}%)"
  end

  def baseline_description
    "#{against_baseline.node.name} on #{against_baseline.date}"
  end
end
